// A macro to show how to print fit parameters into the plot

#include <TH1D.h>
#include <TRandom.h>
#include <TCanvas.h>
#include <TStyle.h>
#include <TF1.h>
#include <TBox.h>

void area() {
    // Remove statbox
    gStyle->SetOptStat(0);

    // Create an empty histogram
    TH1D* h = new TH1D("h", "", 200, 0, 100);

    // Generate some distributions
    TRandom* rand = new TRandom();
    // Generate a gaussian peak
    for (unsigned int i = 0; i < 1e6; i++) {
        h->Fill(rand->Gaus(30, 5), 0.1);
    }
    // Generate background
    for (unsigned int i = 0; i < 1e4; i++) {
        h->Fill(rand->Uniform(0, 100), std::abs(rand->Gaus(0, 10)));
    }

    // Create the canvas
    TCanvas* canvas = new TCanvas("c", "c", 1500, 1200);

    // Draw the histogram
    h->SetMinimum(0);
    h->Draw("hist");

    // Create a gaussian fit function
    TF1* fit_func = new TF1("fit_func", "gaus(0)", 18, 42);

    // Fit the histogram and draw the fit
    h->Fit(fit_func, "R");
    fit_func->Draw("same");

    // Mark (-sigma; +sigma) area of the gaussian fit
    double x1 = fit_func->GetParameter(1) - fit_func->GetParameter(2);
    double x2 = fit_func->GetParameter(1) + fit_func->GetParameter(2);

    // TBox ctor: TBox(x1, y1, x2, y2)
    TBox* area = new TBox(x1, 0, x2, h->GetMaximum()*1.05);
    area->SetLineStyle(9);
    area->SetFillColorAlpha(kOrange+7, 0.2);
    area->Draw();

    // Save the result
    canvas->SaveAs("plots/area.pdf");
    canvas->SaveAs("plots/area.png");
}
