// A macro to show how to print fit parameters into the plot

#include <TH1D.h>
#include <TRandom.h>
#include <TCanvas.h>
#include <TStyle.h>
#include <TF1.h>
#include <TEllipse.h>

void circle() {
    // Remove statbox
    gStyle->SetOptStat(0);

    // Create an empty histogram
    TH1D* h = new TH1D("h", "", 200, 0, 100);

    // Generate some distributions
    TRandom* rand = new TRandom();
    // Generate a gaussian peak
    for (unsigned int i = 0; i < 1e6; i++) {
        h->Fill(rand->Gaus(30, 5), 0.1);
    }
    // Generate background
    for (unsigned int i = 0; i < 1e4; i++) {
        h->Fill(rand->Uniform(0, 100), std::abs(rand->Gaus(0, 10)));
    }

    // Create the canvas
    TCanvas* canvas = new TCanvas("c", "c", 1500, 1200);

    // Draw the histogram
    h->SetMinimum(0);
    h->Draw("hist");

    // Create a gaussian fit function
    TF1* fit_func = new TF1("fit_func", "gaus(0)", 18, 42);

    // Fit the histogram and draw the fit
    h->Fit(fit_func, "R");
    fit_func->Draw("same");

    // Circle radius in some arbitrary units
    float radius = 0.06;
    float xmin = h->GetXaxis()->GetXmin();
    float xmax = h->GetXaxis()->GetXmax();
    float ymin = 0;
    float ymax = h->GetMaximum()*1.1;

    // Draw the circle around fit maximum
    // TEllipse ctor: TLine(x0, y0, r1, r2)
    TEllipse* circle = new TEllipse(fit_func->GetParameter(1), fit_func->GetParameter(0), radius*(xmax-xmin), radius*(ymax-ymin));
    circle->SetFillColorAlpha(0,0);
    circle->Draw();

    // Save the result
    canvas->SaveAs("plots/circle.pdf");
    canvas->SaveAs("plots/circle.png");

}
