
import ROOT
import numpy as np

# Hide statbox
ROOT.gStyle.SetOptStat(0)

# Define bins with progressively larger widths
bins = []
for i in range(10): bins.append(0.1*i)
for i in range(10): bins.append(1 + 0.2*i)
for i in range(5):  bins.append(3 + 0.5*i)
for i in range(3):  bins.append(6 + i)
# Convert bins to a 1-D numpy array
bin_array = np.asarray(bins, np.float64)

for x in bins:
    print(x, end=" ")

# Create a canvas
canvas = ROOT.TCanvas("c", "c", 800, 600)

# Create an empty histogram with custom binning
hist = ROOT.TH1F("hist", "hist", len(bins)-1, bin_array)

# Random number generator
rnd = ROOT.TRandom()
# Fill histogram with an exponential distribution
for i in range(1000000):
    hist.Fill(rnd.Exp(3))

# Draw the histogram
hist.SetMinimum(0)
hist.Draw("hist")

# Save unscaled histogram
canvas.SaveAs("plots/custom_bins_unscaled.pdf")
canvas.SaveAs("plots/custom_bins_unscaled.png")

# Scale bin content with bin width
for b in range(hist.GetNbinsX()):
    width = hist.GetBinWidth(b)
    value = hist.GetBinContent(b)
    hist.SetBinContent(b, value/width)

# Save scaled histogram
canvas.SaveAs("plots/custom_bins_scaled.pdf")
canvas.SaveAs("plots/custom_bins_scaled.png")
