// A macro to show how to print fit parameters into the plot

#include <TH1D.h>
#include <TRandom.h>
#include <TCanvas.h>
#include <TStyle.h>
#include <TF1.h>
#include <TPaveText.h>

void print_fit() {
    // Remove statbox
    gStyle->SetOptStat(0);

    // Create an empty histogram
    TH1D* h = new TH1D("h", "", 100, 0, 100);

    // Generate some distributions
    TRandom* rand = new TRandom();
    // Generate a gaussian peak
    for (unsigned int i = 0; i < 1e5; i++) {
        h->Fill(rand->Gaus(30, 5));
    }
    // Generate background
    for (unsigned int i = 0; i < 1e4; i++) {
        h->Fill(rand->Uniform(0, 100), std::abs(rand->Gaus(0, 10)));
    }

    // Create the canvas
    TCanvas* canvas = new TCanvas("c", "c", 1500, 1200);

    // Draw the histogram
    h->SetMinimum(0);
    h->Draw("hist");

    // Create a gaussian fit function
    TF1* fit_func = new TF1("fit_func", "gaus(0)", 18, 42);

    // Fit the histogram and draw the fit
    h->Fit(fit_func, "R");
    fit_func->Draw("same");

    // Get fit parameters as strings
    double cnst = fit_func->GetParameter(0);
    double mean = fit_func->GetParameter(1);
    double sigma = fit_func->GetParameter(2);

    // Print the fit parameters using TPaveText object
    // TPaveText ctor: TPaveText(x1, y1, x2, y2, coordinate_type)
    TPaveText* text = new TPaveText(0.65, 0.55, 0.85, 0.80, "NDC");
    // Set text size
    text->SetTextSize(0.030);
    // Set text alignment to left-aligned
    text->SetTextAlign(11);
    // No fill color
    text->SetFillColor(0);
    // Add text lines
    text->AddText("f(x) = Ce^{- #frac{(x-x_{0})^{2}}{2#sigma^{2}}}");
    text->AddText("");
    text->AddText("Fit results:");
    text->AddText(("C = " + std::to_string(cnst)).c_str());
    text->AddText(("x_{0} = " + std::to_string(mean)).c_str());
    text->AddText(("#sigma = " + std::to_string(sigma)).c_str());
    text->AddText("");
    text->AddText(("Fit chi2/NDF = " + std::to_string(fit_func->GetChisquare()) + "/" + std::to_string(fit_func->GetNDF())).c_str());
    // Draw the TPaveText object
    text->Draw("same");

    // Save the result
    canvas->SaveAs("plots/print_fit.pdf");
    canvas->SaveAs("plots/print_fit.png");

}
